==> spacejunk-1.0.3.tar.gz: spacejunk-1.0.3/src/sjsound.cpp <==
/*
  Copyright (C) 2009 Facundo Domínguez 

  This file is part of Spacejunk.

  Spacejunk is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Foobar is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "graphic.h"
#include "gcnlayouts.h"
#include "resourcemanager.h"
#include <guichan.hpp>
#include <guichan/sdl.hpp>
#include <iostream>
#include <fstream>
#include "SDL_mixer.h"
#include "soundfx.h"
#include "cmask.h"
#include "readconfig.h"
#include <unistd.h>

using namespace gcn;
using namespace std;


int bellx,belly,bellw,bellh;

Soundfx * bl;
int mx=0,my=0;

#define point_inside(w,h,x,y) (0<=(x) && (x)<(w) && 0<=(y) && (y)<(h))

bool GUI_process_events(SDLInput * input,SDLGraphics * graphics) {
    SDL_Event e;
    int i=0;
    while (SDL_PollEvent(&e) && i<30) {
        switch (e.type) {
        case SDL_KEYDOWN:
            switch (e.key.keysym.sym) {
            case SDLK_ESCAPE:
                return false;
            default:
                ;
            }
            break;
        case SDL_MOUSEMOTION:
            mx=e.motion.x;
            my=e.motion.y;
            break;
        case SDL_MOUSEBUTTONDOWN:
            if (e.button.button==SDL_BUTTON_LEFT && point_inside(bellw,bellh,e.button.x-bellx,e.button.y-belly))
                bl->play();
            break;
        case SDL_QUIT:
            return false;
        default:
            ;
        }
        input->pushInput(e);
        i++;
    };

    return true;
}


class IntSlider : public gcn::Slider {
public:
    IntSlider(int scaleStart,int scaleEnd) : gcn::Slider(scaleStart,scaleEnd) {};
    void setValue(double v) {
        gcn::Slider::setValue(int(v));
    }
};

class SldListener : public gcn::MouseListener {
private:
    gcn::Slider * sld;
    bool in,pressIn;
public:
    SldListener(gcn::Slider * sld) :sld(sld),in(false),pressIn(false) {};
    void mouseRelease(int x, int y, int button) {
        if (!pressIn) return;

        delete bl;
        Mix_CloseAudio();
        if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS,int(pow(2,int(sld->getValue()))))) {
            cerr<<"Could not reinitialize audio system: "<<Mix_GetError()<<"\n";
            exit(1);
        };
        bl=new Soundfx("TimeForward");
    }

    void mousePress(int x, int y, int button) {
        pressIn=in;
    }
    void mouseIn() {
        in=true;
    }
    void mouseOut() {
        in=false;
    }
};

class SoundAction : public ActionListener {
    bool * q;
public:
    SoundAction(bool * q) : q(q) {};
    void action(const ActionEvent& actionEvent) {
        if (actionEvent.getId()=="quit") *q=true;
        else if (actionEvent.getId()=="setaudiobuffer") {
        }
    }
};


typedef enum { ALL=0x0F,
               AUDIO=0x01,
               VIDEO=0x02 ,
             } CLEANUP;

void cleanUp(int flags) {
    if (VIDEO & flags) {
        // Ensure that we leave the program in windowed mode.
        // This is mainly for avoiding living screen in a mode
        // different from the one used when the program was started.
        SDL_Surface * s=SDL_GetVideoSurface();
        if (s->flags & SDL_FULLSCREEN) {
            SDL_SetVideoMode(s->w,s->h,s->format->BitsPerPixel,0);
        }
    }
    if (AUDIO & flags) {
        Mix_CloseAudio();
    }
    if (VIDEO & flags) SDL_Quit();
}

void cleanUp() {
    cleanUp(ALL);
};

void fillLoaderList(list<RLoader*> & rl) {
    rl.push_back(Singleton<PaletteLoader>::getInstance());
    rl.push_back(Singleton<ImageSetLoader>::getInstance());
    rl.push_back(Singleton<CMaskLoader>::getInstance());
    rl.push_back(Singleton<MusicLoader>::getInstance());
    rl.push_back(Singleton<SoundLoader>::getInstance());
    rl.push_back(Singleton<FontLoader>::getInstance());
}


int main(int argc,char** argv) {


    // up SDL
    if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE) != 0) {
        cerr<<"Unable to initialize SDL: "<<SDL_GetError()<<"\n";
        exit(1);
    }
    SDL_EnableUNICODE(1);

    // load resources
    list<RLoader*> rl;
    fillLoaderList(rl);
    readResources("data/resources.xml",rl);

    // up the video
    Graphic::set_video_mode(640,480);

    SDL_ShowCursor(SDL_DISABLE);

    // up the audio
    if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS,int(pow(2,9)))) {
        cleanUp(VIDEO);
        cerr<<"Could not initialize audio system: "<<Mix_GetError()<<"\n";
        exit(1);
    };

    if (atexit(&cleanUp)) {
        cleanUp();
        cerr<<"Could not set up exit tasks.\n";
        exit(1);
    }

    Config cfg;
    if (!access("config.txt",F_OK)) {
        readconfig("config.txt",&cfg);
    };


    // up guichan
    SDLImageLoader imageLoader;
    Image::setImageLoader(&imageLoader);
    SDLGraphics graphics;
    graphics.setTarget(Graphic::getScreen());
    RMFONTRef font("12p");
	gcn::Widget::setGlobalFont(&*font);
    SDLInput input;

    //  ButtonPress state=QUITBT;
    bool quit=false;

    bl=new Soundfx("TimeForward");
    IntSlider slds(8,13);
    SoundAction a(&quit);
    SldListener slistener(&slds);
    Layout c;
    slds.setDimension(gcn::Rectangle(0,0,10,70));
    slds.setOrientation(gcn::Slider::VERTICAL);
    slds.setValue(cfg.audiobuffer);
    slds.setStepLength(1);
    slds.setActionEventId("setaudiobuffer");
    slds.addActionListener(&a);
    slds.addMouseListener(&slistener);
    Button btQuit("Quit");
    btQuit.addActionListener(&a);
    btQuit.setActionEventId("quit");
    c.add(&slds,0,0);
    c.add(&btQuit,50,50);
    c.fitWidgets();
    c.setPosition(int(Graphic::screencenter.x-c.getWidth()/2),int(Graphic::screencenter.y-c.getHeight()/2));
    c.setOpaque(false);
    Gui gui;
    gui.setGraphics(&graphics);
    gui.setInput(&input);
    gui.setTop(&c);

    Graphic mpointer("mousepointer");
    mpointer.hotspot=Vector2d();
    Graphic bell("bell");
    bell.hotspot=Vector2d();
    bellx=320;
    belly=200;
    bellw=int(bell.getWidth());
    bellh=int(bell.getHeight());

    string text=
        "  This program will tune the game sound in order to avoid\
        \nsound delays or sound skipping during gameplay.\
        \n  Click on the bell, you should hear a sound.\
        \n  If you notice a delay between clicking and hearing lower\
        \nthe slider and try again.\
        \n  If the sound skips raise the slider and try again.\
        \n  Quit when you think that the test is OK.";


    while (!quit && GUI_process_events(&input,&graphics)) {
        Graphic::clearScreen(SDL_MapRGB(Graphic::getScreen()->format, 0, 0,0));
        gui.logic();
        gui.draw();
        bell.draw(bellx,belly);
        font->draw(50,25,text);
        mpointer.draw(mx,my);
        Graphic::flip();
        Graphic::sleep(33);
    }

    cfg.audiobuffer=int(slds.getValue());

    ofstream f("config.txt");
    f<<cfg;

    return 0;
}

==> spacejunk-1.0.5.tar.gz: spacejunk-1.0.5/src/sjsound.cpp <==
/*
  Copyright (C) 2009 Facundo Domínguez 

  This file is part of Spacejunk.

  Spacejunk is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Foobar is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "graphic.h"
#include "gcnlayouts.h"
#include "resourcemanager.h"
#include <guichan.hpp>
#include <guichan/sdl.hpp>
#include <iostream>
#include <fstream>
#include "SDL_mixer.h"
#include "soundfx.h"
#include "cmask.h"
#include "readconfig.h"
#include <unistd.h>

using namespace gcn;
using namespace std;


int bellx,belly,bellw,bellh;

Soundfx * bl;
int mx=0,my=0;

#define point_inside(w,h,x,y) (0<=(x) && (x)<(w) && 0<=(y) && (y)<(h))

bool GUI_process_events(SDLInput * input,SDLGraphics * graphics) {
    SDL_Event e;
    int i=0;
    while (SDL_PollEvent(&e) && i<30) {
        switch (e.type) {
        case SDL_KEYDOWN:
            switch (e.key.keysym.sym) {
            case SDLK_ESCAPE:
                return false;
            default:
                ;
            }
            break;
        case SDL_MOUSEMOTION:
            mx=e.motion.x;
            my=e.motion.y;
            break;
        case SDL_MOUSEBUTTONDOWN:
            if (e.button.button==SDL_BUTTON_LEFT && point_inside(bellw,bellh,e.button.x-bellx,e.button.y-belly))
                bl->play();
            break;
        case SDL_QUIT:
            return false;
        default:
            ;
        }
        input->pushInput(e);
        i++;
    };

    return true;
}


class IntSlider : public gcn::Slider {
public:
    IntSlider(int scaleStart,int scaleEnd) : gcn::Slider(scaleStart,scaleEnd) {};
    void setValue(double v) {
        gcn::Slider::setValue(int(v));
    }
};

class SldListener : public gcn::MouseListener {
private:
    gcn::Slider * sld;
    bool in,pressIn;
public:
    SldListener(gcn::Slider * sld) :sld(sld),in(false),pressIn(false) {};
    void mouseRelease(int x, int y, int button) {
        if (!pressIn) return;

        delete bl;
        Mix_CloseAudio();
        if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS,int(pow(2,int(sld->getValue()))))) {
            cerr<<"Could not reinitialize audio system: "<<Mix_GetError()<<"\n";
            exit(1);
        };
        bl=new Soundfx("TimeForward");
    }

    void mousePress(int x, int y, int button) {
        pressIn=in;
    }
    void mouseIn() {
        in=true;
    }
    void mouseOut() {
        in=false;
    }
};

class SoundAction : public ActionListener {
    bool * q;
public:
    SoundAction(bool * q) : q(q) {};
    void action(const ActionEvent& actionEvent) {
        if (actionEvent.getId()=="quit") *q=true;
        else if (actionEvent.getId()=="setaudiobuffer") {
        }
    }
};


typedef enum { ALL=0x0F,
               AUDIO=0x01,
               VIDEO=0x02 ,
             } CLEANUP;

void cleanUp(int flags) {
    if (VIDEO & flags) {
        // Ensure that we leave the program in windowed mode.
        // This is mainly for avoiding living screen in a mode
        // different from the one used when the program was started.
        SDL_Surface * s=SDL_GetVideoSurface();
        if (s->flags & SDL_FULLSCREEN) {
            SDL_SetVideoMode(s->w,s->h,s->format->BitsPerPixel,0);
        }
    }
    if (AUDIO & flags) {
        Mix_CloseAudio();
    }
    if (VIDEO & flags) SDL_Quit();
}

void cleanUp() {
    cleanUp(ALL);
};

void fillLoaderList(list<RLoader*> & rl) {
    rl.push_back(Singleton<PaletteLoader>::getInstance());
    rl.push_back(Singleton<ImageSetLoader>::getInstance());
    rl.push_back(Singleton<CMaskLoader>::getInstance());
    rl.push_back(Singleton<MusicLoader>::getInstance());
    rl.push_back(Singleton<SoundLoader>::getInstance());
    rl.push_back(Singleton<FontLoader>::getInstance());
}


int main(int argc,char** argv) {


    // up SDL
    if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_AUDIO | SDL_INIT_NOPARACHUTE) != 0) {
        cerr<<"Unable to initialize SDL: "<<SDL_GetError()<<"\n";
        exit(1);
    }
    SDL_EnableUNICODE(1);

    // load resources
    list<RLoader*> rl;
    fillLoaderList(rl);
    readResources(GetDataPath()+"resources.xml",rl);

    // up the video
    Graphic::set_video_mode(640,480);

    SDL_ShowCursor(SDL_DISABLE);

    // up the audio
    if (Mix_OpenAudio(MIX_DEFAULT_FREQUENCY, MIX_DEFAULT_FORMAT, MIX_DEFAULT_CHANNELS,int(pow(2,9)))) {
        cleanUp(VIDEO);
        cerr<<"Could not initialize audio system: "<<Mix_GetError()<<"\n";
        exit(1);
    };

    if (atexit(&cleanUp)) {
        cleanUp();
        cerr<<"Could not set up exit tasks.\n";
        exit(1);
    }

    Config cfg;
    if (!access("config.txt",F_OK)) {
        readconfig("config.txt",&cfg);
    };


    // up guichan
    SDLImageLoader imageLoader;
    Image::setImageLoader(&imageLoader);
    SDLGraphics graphics;
    graphics.setTarget(Graphic::getScreen());
    RMFONTRef font("12p");
	gcn::Widget::setGlobalFont(&*font);
    SDLInput input;

    //  ButtonPress state=QUITBT;
    bool quit=false;

    bl=new Soundfx("TimeForward");
    IntSlider slds(8,13);
    SoundAction a(&quit);
    SldListener slistener(&slds);
    Layout c;
    slds.setDimension(gcn::Rectangle(0,0,10,70));
    slds.setOrientation(gcn::Slider::VERTICAL);
    slds.setValue(cfg.audiobuffer);
    slds.setStepLength(1);
    slds.setActionEventId("setaudiobuffer");
    slds.addActionListener(&a);
    slds.addMouseListener(&slistener);
    Button btQuit("Quit");
    btQuit.addActionListener(&a);
    btQuit.setActionEventId("quit");
    c.add(&slds,0,0);
    c.add(&btQuit,50,50);
    c.fitWidgets();
    c.setPosition(int(Graphic::screencenter.x-c.getWidth()/2),int(Graphic::screencenter.y-c.getHeight()/2));
    c.setOpaque(false);
    Gui gui;
    gui.setGraphics(&graphics);
    gui.setInput(&input);
    gui.setTop(&c);

    Graphic mpointer("mousepointer");
    mpointer.hotspot=Vector2d();
    Graphic bell("bell");
    bell.hotspot=Vector2d();
    bellx=320;
    belly=200;
    bellw=int(bell.getWidth());
    bellh=int(bell.getHeight());

    string text=
        "  This program will tune the game sound in order to avoid\
        \nsound delays or sound skipping during gameplay.\
        \n  Click on the bell, you should hear a sound.\
        \n  If you notice a delay between clicking and hearing lower\
        \nthe slider and try again.\
        \n  If the sound skips raise the slider and try again.\
        \n  Quit when you think that the test is OK.";


    while (!quit && GUI_process_events(&input,&graphics)) {
        Graphic::clearScreen(SDL_MapRGB(Graphic::getScreen()->format, 0, 0,0));
        gui.logic();
        gui.draw();
        bell.draw(bellx,belly);
        font->draw(50,25,text);
        mpointer.draw(mx,my);
        Graphic::flip();
        Graphic::sleep(33);
    }

    cfg.audiobuffer=int(slds.getValue());

    ofstream f("config.txt");
    f<<cfg;

    return 0;
}
